<?php
/**
 * CSB V2-Payment Module version 1.10.0 for PrestaShop 1.5-1.7. Support contact : hotline-epaync@csb.nc.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/afl-3.0.php
 *
 * @author    Lyra Network (http://www.lyra-network.com/)
 * @copyright 2014-2018 Lyra Network and contributors
 * @license   https://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * @category  payment
 * @package   csb
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class that renders CSB payment module administration interface.
 */
class CsbHelperForm
{
    private function __construct()
    {
        // do not instantiate this class
    }

    public static function getAdminFormContext()
    {
        $context = Context::getContext();

        /* @var Csb */
        $csb = Module::getInstanceByName('csb');

        $languages = array();
        foreach (CsbApi::getSupportedLanguages() as $code => $label) {
            $languages[$code] = $csb->l($label, 'csbhelperform');
        }
        asort($languages);

        $category_options = array(
            'FOOD_AND_GROCERY' => $csb->l('Food and grocery', 'csbhelperform'),
            'AUTOMOTIVE' => $csb->l('Automotive', 'csbhelperform'),
            'ENTERTAINMENT' => $csb->l('Entertainment', 'csbhelperform'),
            'HOME_AND_GARDEN' => $csb->l('Home and garden', 'csbhelperform'),
            'HOME_APPLIANCE' => $csb->l('Home appliance', 'csbhelperform'),
            'AUCTION_AND_GROUP_BUYING' => $csb->l('Auction and group buying', 'csbhelperform'),
            'FLOWERS_AND_GIFTS' => $csb->l('Flowers and gifts', 'csbhelperform'),
            'COMPUTER_AND_SOFTWARE' => $csb->l('Computer and software', 'csbhelperform'),
            'HEALTH_AND_BEAUTY' => $csb->l('Health and beauty', 'csbhelperform'),
            'SERVICE_FOR_INDIVIDUAL' => $csb->l('Service for individual', 'csbhelperform'),
            'SERVICE_FOR_BUSINESS' => $csb->l('Service for business', 'csbhelperform'),
            'SPORTS' => $csb->l('Sports', 'csbhelperform'),
            'CLOTHING_AND_ACCESSORIES' => $csb->l('Clothing and accessories', 'csbhelperform'),
            'TRAVEL' => $csb->l('Travel', 'csbhelperform'),
            'HOME_AUDIO_PHOTO_VIDEO' => $csb->l('Home audio, photo, video', 'csbhelperform'),
            'TELEPHONY' => $csb->l('Telephony', 'csbhelperform')
        );

        // get documentation links
        $doc_files = array();
        $filenames = glob(_PS_MODULE_DIR_.'csb/installation_doc/CSB_PrestaShop_1.5-1.7_v1.10.0*.pdf');

        $doc_languages = array(
            'fr' => 'Français',
            'en' => 'English',
            'es' => 'Español'
            // complete when other languages are managed
        );

        foreach ($filenames as $filename) {
            $base_filename = basename($filename, '.pdf');
            $lang = Tools::substr($base_filename, -2); // extract language code

            $doc_files[$base_filename.'.pdf'] = $doc_languages[$lang];
        }

        $tpl_vars = array(
            'csb_plugin_features' => CsbTools::$plugin_features,
            'csb_request_uri' => $_SERVER['REQUEST_URI'],

            'csb_doc_files' => $doc_files,
            'csb_enable_disable_options' => array(
                'False' => $csb->l('Disabled', 'csbhelperform'),
                'True' => $csb->l('Enabled', 'csbhelperform')
            ),
            'csb_mode_options' => array(
                'TEST' => $csb->l('TEST', 'csbhelperform'),
                'PRODUCTION' => $csb->l('PRODUCTION', 'csbhelperform')
            ),
            'csb_language_options' => $languages,
            'csb_validation_mode_options' => array(
                '' => $csb->l('Back office configuration', 'csbhelperform'),
                '0' => $csb->l('Automatic', 'csbhelperform'),
                '1' => $csb->l('Manual', 'csbhelperform')
            ),
            'csb_payment_cards_options' => array('' => $csb->l('ALL', 'csbhelperform')) + CsbTools::getSupportedCardTypes(),
            'csb_multi_payment_cards_options' => array('' => $csb->l('ALL', 'csbhelperform')) + CsbTools::getSupportedMultiCardTypes(),
            'csb_category_options' => $category_options,
            'csb_yes_no_options' => array(
                'False' => $csb->l('No', 'csbhelperform'),
                'True' => $csb->l('Yes', 'csbhelperform')
            ),
            'csb_delivery_type_options' => array(
                'PACKAGE_DELIVERY_COMPANY' => $csb->l('Delivery company', 'csbhelperform'),
                'RECLAIM_IN_SHOP' => $csb->l('Reclaim in shop', 'csbhelperform'),
                'RELAY_POINT' => $csb->l('Relay point', 'csbhelperform'),
                'RECLAIM_IN_STATION' => $csb->l('Reclaim in station', 'csbhelperform')
            ),
            'csb_delivery_speed_options' => array(
                'STANDARD' => $csb->l('Standard', 'csbhelperform'),
                'EXPRESS' => $csb->l('Express', 'csbhelperform'),
                'PRIORITY' => $csb->l('Priority', 'csbhelperform')
            ),
            'csb_delivery_delay_options' => array(
                'INFERIOR_EQUALS' => $csb->l('<= 1 hour', 'csbhelperform'),
                'SUPERIOR' => $csb->l('> 1 hour', 'csbhelperform'),
                'IMMEDIATE' => $csb->l('Immediate', 'csbhelperform'),
                'ALWAYS' => $csb->l('24/7', 'csbhelperform')
            ),
            'csb_failure_management_options' => array(
                CsbTools::ON_FAILURE_RETRY => $csb->l('Go back to checkout', 'csbhelperform'),
                CsbTools::ON_FAILURE_SAVE => $csb->l('Save order and go back to order history', 'csbhelperform')
            ),
            'csb_cart_management_options' => array(
                CsbTools::EMPTY_CART => $csb->l('Empty cart to avoid amount errors', 'csbhelperform'),
                CsbTools::KEEP_CART => $csb->l('Keep cart (PrestaShop default behavior)', 'csbhelperform')
            ),
            'csb_card_data_mode_options' => array(
                '1' => $csb->l('Bank data acquisition on payment gateway', 'csbhelperform'),
                '2' => $csb->l('Card type selection on merchant site', 'csbhelperform'),
                '3' => $csb->l('Bank data acquisition on merchant site', 'csbhelperform'),
                '4' => $csb->l('Payment page integrated to checkout process (iframe mode)', 'csbhelperform')
            ),
            'csb_card_selection_mode_options' => array(
                '1' => $csb->l('On payment gateway', 'csbhelperform'),
                '2' => $csb->l('On merchant site', 'csbhelperform')
            ),
            'csb_default_multi_option' => array(
                'label' => '',
                'min_amount' => '',
                'max_amount' => '',
                'contract' => '',
                'count' => '',
                'period' => '',
                'first' => ''
            ),
            'csb_default_oney_option' => array(
                'label' => '',
                'code' => '',
                'min_amount' => '',
                'max_amount' => '',
                'count' => '',
                'rate' => ''
            ),

            'prestashop_categories' => Category::getCategories((int)$context->language->id, true, false),
            'prestashop_languages' => Language::getLanguages(false),
            'prestashop_lang' => Language::getLanguage((int)$context->language->id),
            'prestashop_carriers' => Carrier::getCarriers(
                (int)$context->language->id,
                true,
                false,
                false,
                null,
                Carrier::ALL_CARRIERS
            ),
            'prestashop_groups' => self::getAuthorizedGroups(),

            'CSB_ENABLE_LOGS' => Configuration::get('CSB_ENABLE_LOGS'),

            'CSB_SITE_ID' => Configuration::get('CSB_SITE_ID'),
            'CSB_KEY_TEST' => Configuration::get('CSB_KEY_TEST'),
            'CSB_KEY_PROD' => Configuration::get('CSB_KEY_PROD'),
            'CSB_MODE' => Configuration::get('CSB_MODE'),
            'CSB_SIGN_ALGO' => Configuration::get('CSB_SIGN_ALGO'),
            'CSB_PLATFORM_URL' => Configuration::get('CSB_PLATFORM_URL'),
            'CSB_NOTIFY_URL' => self::getIpnUrl(),

            'CSB_DEFAULT_LANGUAGE' => Configuration::get('CSB_DEFAULT_LANGUAGE'),
            'CSB_AVAILABLE_LANGUAGES' => !Configuration::get('CSB_AVAILABLE_LANGUAGES') ?
                                            array('') :
                                            explode(';', Configuration::get('CSB_AVAILABLE_LANGUAGES')),
            'CSB_DELAY' => Configuration::get('CSB_DELAY'),
            'CSB_VALIDATION_MODE' => Configuration::get('CSB_VALIDATION_MODE'),

            'CSB_THEME_CONFIG' => Configuration::get('CSB_THEME_CONFIG'),
            'CSB_SHOP_NAME' => Configuration::get('CSB_SHOP_NAME'),
            'CSB_SHOP_URL' => Configuration::get('CSB_SHOP_URL'),

            'CSB_3DS_MIN_AMOUNT' => self::getArrayConfig('CSB_3DS_MIN_AMOUNT'),

            'CSB_REDIRECT_ENABLED' => Configuration::get('CSB_REDIRECT_ENABLED'),
            'CSB_REDIRECT_SUCCESS_T' => Configuration::get('CSB_REDIRECT_SUCCESS_T'),
            'CSB_REDIRECT_SUCCESS_M' => self::getLangConfig('CSB_REDIRECT_SUCCESS_M'),
            'CSB_REDIRECT_ERROR_T' => Configuration::get('CSB_REDIRECT_ERROR_T'),
            'CSB_REDIRECT_ERROR_M' => self::getLangConfig('CSB_REDIRECT_ERROR_M'),
            'CSB_RETURN_MODE' => Configuration::get('CSB_RETURN_MODE'),
            'CSB_FAILURE_MANAGEMENT' => Configuration::get('CSB_FAILURE_MANAGEMENT'),
            'CSB_CART_MANAGEMENT' => Configuration::get('CSB_CART_MANAGEMENT'),

            'CSB_COMMON_CATEGORY' => Configuration::get('CSB_COMMON_CATEGORY'),
            'CSB_CATEGORY_MAPPING' => self::getArrayConfig('CSB_CATEGORY_MAPPING'),
            'CSB_SEND_SHIP_DATA' => Configuration::get('CSB_SEND_SHIP_DATA'),
            'CSB_ONEY_SHIP_OPTIONS' => self::getArrayConfig('CSB_ONEY_SHIP_OPTIONS'),

            'CSB_STD_TITLE' => self::getLangConfig('CSB_STD_TITLE'),
            'CSB_STD_ENABLED' => Configuration::get('CSB_STD_ENABLED'),
            'CSB_STD_AMOUNTS' => self::getArrayConfig('CSB_STD_AMOUNTS'),
            'CSB_STD_DELAY' => Configuration::get('CSB_STD_DELAY'),
            'CSB_STD_VALIDATION' => Configuration::get('CSB_STD_VALIDATION'),
            'CSB_STD_PAYMENT_CARDS' => !Configuration::get('CSB_STD_PAYMENT_CARDS') ?
                                            array('') :
                                            explode(';', Configuration::get('CSB_STD_PAYMENT_CARDS')),
            'CSB_STD_PROPOSE_ONEY' => Configuration::get('CSB_STD_PROPOSE_ONEY'),
            'CSB_STD_CARD_DATA_MODE' => Configuration::get('CSB_STD_CARD_DATA_MODE'),

            'CSB_MULTI_TITLE' => self::getLangConfig('CSB_MULTI_TITLE'),
            'CSB_MULTI_ENABLED' => Configuration::get('CSB_MULTI_ENABLED'),
            'CSB_MULTI_AMOUNTS' => self::getArrayConfig('CSB_MULTI_AMOUNTS'),
            'CSB_MULTI_DELAY' => Configuration::get('CSB_MULTI_DELAY'),
            'CSB_MULTI_VALIDATION' => Configuration::get('CSB_MULTI_VALIDATION'),
            'CSB_MULTI_CARD_MODE' => Configuration::get('CSB_MULTI_CARD_MODE'),
            'CSB_MULTI_PAYMENT_CARDS' => !Configuration::get('CSB_MULTI_PAYMENT_CARDS') ?
                                            array('') :
                                            explode(';', Configuration::get('CSB_MULTI_PAYMENT_CARDS')),
            'CSB_MULTI_OPTIONS' => self::getArrayConfig('CSB_MULTI_OPTIONS'),

            'CSB_ANCV_TITLE' => self::getLangConfig('CSB_ANCV_TITLE'),
            'CSB_ANCV_ENABLED' => Configuration::get('CSB_ANCV_ENABLED'),
            'CSB_ANCV_AMOUNTS' => self::getArrayConfig('CSB_ANCV_AMOUNTS'),
            'CSB_ANCV_DELAY' => Configuration::get('CSB_ANCV_DELAY'),
            'CSB_ANCV_VALIDATION' => Configuration::get('CSB_ANCV_VALIDATION'),

            'CSB_ONEY_TITLE' => self::getLangConfig('CSB_ONEY_TITLE'),
            'CSB_ONEY_ENABLED' => Configuration::get('CSB_ONEY_ENABLED'),
            'CSB_ONEY_AMOUNTS' => self::getArrayConfig('CSB_ONEY_AMOUNTS'),
            'CSB_ONEY_DELAY' => Configuration::get('CSB_ONEY_DELAY'),
            'CSB_ONEY_VALIDATION' => Configuration::get('CSB_ONEY_VALIDATION'),
            'CSB_ONEY_ENABLE_OPTIONS' => Configuration::get('CSB_ONEY_ENABLE_OPTIONS'),
            'CSB_ONEY_OPTIONS' => self::getArrayConfig('CSB_ONEY_OPTIONS'),

            'CSB_FULLCB_TITLE' => self::getLangConfig('CSB_FULLCB_TITLE'),
            'CSB_FULLCB_ENABLED' => Configuration::get('CSB_FULLCB_ENABLED'),
            'CSB_FULLCB_AMOUNTS' => self::getArrayConfig('CSB_FULLCB_AMOUNTS'),
            'CSB_FULLCB_ENABLE_OPTS' => Configuration::get('CSB_FULLCB_ENABLE_OPTS'),
            'CSB_FULLCB_OPTIONS' => self::getArrayConfig('CSB_FULLCB_OPTIONS'),

            'CSB_SEPA_TITLE' => self::getLangConfig('CSB_SEPA_TITLE'),
            'CSB_SEPA_ENABLED' => Configuration::get('CSB_SEPA_ENABLED'),
            'CSB_SEPA_AMOUNTS' => self::getArrayConfig('CSB_SEPA_AMOUNTS'),
            'CSB_SEPA_DELAY' => Configuration::get('CSB_SEPA_DELAY'),
            'CSB_SEPA_VALIDATION' => Configuration::get('CSB_SEPA_VALIDATION'),

            'CSB_SOFORT_TITLE' => self::getLangConfig('CSB_SOFORT_TITLE'),
            'CSB_SOFORT_ENABLED' => Configuration::get('CSB_SOFORT_ENABLED'),
            'CSB_SOFORT_AMOUNTS' => self::getArrayConfig('CSB_SOFORT_AMOUNTS'),

            'CSB_PAYPAL_TITLE' => self::getLangConfig('CSB_PAYPAL_TITLE'),
            'CSB_PAYPAL_ENABLED' => Configuration::get('CSB_PAYPAL_ENABLED'),
            'CSB_PAYPAL_AMOUNTS' => self::getArrayConfig('CSB_PAYPAL_AMOUNTS'),
            'CSB_PAYPAL_DELAY' => Configuration::get('CSB_PAYPAL_DELAY'),
            'CSB_PAYPAL_VALIDATION' => Configuration::get('CSB_PAYPAL_VALIDATION'),

            'CSB_CHOOZEO_TITLE' => self::getLangConfig('CSB_CHOOZEO_TITLE'),
            'CSB_CHOOZEO_ENABLED' => Configuration::get('CSB_CHOOZEO_ENABLED'),
            'CSB_CHOOZEO_AMOUNTS' => self::getArrayConfig('CSB_CHOOZEO_AMOUNTS'),
            'CSB_CHOOZEO_DELAY' => Configuration::get('CSB_CHOOZEO_DELAY'),
            'CSB_CHOOZEO_OPTIONS' => self::getArrayConfig('CSB_CHOOZEO_OPTIONS')
        );

        if (!CsbTools::$plugin_features['acquis']) {
            unset($tpl_vars['csb_card_data_mode_options']['3']);
        }

        return $tpl_vars;
    }

    private static function getIpnUrl()
    {
        $shop = new Shop(Configuration::get('PS_SHOP_DEFAULT'));

        // ssl enabled on default shop ?
        $id_shop_group = isset($shop->id_shop_group) ? $shop->id_shop_group : $shop->id_group_shop;
        $ssl = Configuration::get('PS_SSL_ENABLED', null, $id_shop_group, $shop->id);

        $ipn = ($ssl ? 'https://'.$shop->domain_ssl : 'http://'.$shop->domain)
               .$shop->getBaseURI().'modules/csb/validation.php';

        return $ipn;
    }

    private static function getArrayConfig($name)
    {
        $value = @unserialize(Configuration::get($name));

        if (!is_array($value)) {
            $value = array();
        }

        return $value;
    }

    private static function getLangConfig($name)
    {
        $languages = Language::getLanguages(false);

        $result = array();
        foreach ($languages as $language) {
            $result[$language['id_lang']] = Configuration::get($name, $language['id_lang']);
        }

        return $result;
    }

    private static function getAuthorizedGroups()
    {
        $context = Context::getContext();

        /* @var Csb */
        $csb = Module::getInstanceByName('csb');

        $sql = 'SELECT DISTINCT gl.`id_group`, gl.`name` FROM `'._DB_PREFIX_.'group_lang` AS gl
            INNER JOIN `'._DB_PREFIX_.'module_group` AS mg
            ON (
                gl.`id_group` = mg.`id_group`
                AND mg.`id_module` = '.(int)$csb->id.'
                AND mg.`id_shop` = '.(int)$context->shop->id.'
            )
            WHERE gl.`id_lang` = '.(int)$context->language->id;

        return Db::getInstance()->executeS($sql);
    }
}
